MagicModelWatcher class

TelescopeWatcher that subscribes to ModelCreated, ModelSaved, ModelDeleted and feeds TelescopeStore.recordMagicModel.

Registers three listener factories with EventDispatcher ; magic's dispatcher invokes the factory once per dispatch and calls the listener's handle method.

Constructors

MagicModelWatcher()

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Human-readable watcher name.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

install() → void
Wire the watcher's listening hook (event subscription, override, etc.).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
uninstall() → void
Tear down the hook (test isolation).

Operators

operator ==(Object other) bool
The equality operator.
inherited